Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
var BinaryCommand = []string{"create", "-n"}
var BinaryLocation = ProjectPath + "kedge"
var ProjectPath = "$GOPATH/src/github.com/kedgeproject/kedge/"
Hardcoding the location of the binary, which is in root of project directory
var TestPath = "docs/examples/"
Functions ¶
func PodsStarted ¶
func PodsStarted(t *testing.T, clientset *kubernetes.Clientset, namespace string, podNames []string) error
Check to see if specific pods have been started
func RunBinary ¶
Run the binary against the Kubernetes cluster using a specified command against a specific namespace requirement: your binary must have a --namespace parameter to specify a namespace location as well as -f to specific a file. Ex: command --namespace foobar -f foo.yaml -f bar.yaml
Types ¶
Source Files
¶
- e2e.go
Click to show internal directories.
Click to hide internal directories.